<?php
/**
 * Created by PhpStorm.
 * User: migue
 * Date: 02/06/2017
 * Time: 12:06
 */

namespace Oct8ne\Oct8ne\Controller\Frame;

use \Magento\Framework\App\Action\Context;
use \Oct8ne\Oct8ne\Helper\ResponseHelper;
use \Magento\Framework\App\Config\ScopeConfigInterface;
use \Magento\Sales\Model\ResourceModel\Order\CollectionFactory;
use \Oct8ne\Oct8ne\Helper\Oct8neContextHelper;
use \Magento\Framework\Pricing\PriceCurrencyInterface as CurrencyHelper;
use \Magento\Sales\Api\OrderRepositoryInterface;
use \Magento\Framework\Api\SearchCriteriaBuilder;
use \Oct8ne\Oct8ne\Helper\CheckCredentials;
use \Magento\Framework\Module\Manager;

class GetOrderDetails extends \Magento\Framework\App\Action\Action
{

    /**
     * @var ProductSummaryHelper|Oct8neModuleInfoHelper
     */
    protected $_oct8necontext;

    protected $_scopeconfig;

    protected $_orderCollectionFactory;

    /**
     * @var Context
     */
    protected $_context;

    protected $_responseHelper;


    protected $_currencyHelper;

    protected $_orderRepository;

    protected $_searchCriteriaBuilder;

    protected $_credentials;

    protected $_storeManager;
    
    protected $_moduleManager;

    protected $_storeId;
    /**
     * Inyeccion de dependencias. Inyectamos lo que nos hace falta
     * GetAdapterInfo constructor.
     * @param Context $context
     * @param ProductSummaryHelper $helper
     */

    public function __construct(Context $context, Oct8neContextHelper $oct8necontext, ResponseHelper $responseHelper, ScopeConfigInterface $scope, CollectionFactory $orderCollectionFactory, CurrencyHelper $currencyHelper, OrderRepositoryInterface $orderRepository, SearchCriteriaBuilder $searchCriteriaBuilder, CheckCredentials $check, Manager $moduleManager)
    {
        $this->_context = $context;
        $this->_oct8necontext = $oct8necontext;
        $this->_responseHelper = $responseHelper;
        $this->_scopeconfig = $scope;
        $this->_orderCollectionFactory = $orderCollectionFactory;
        $this->_currencyHelper = $currencyHelper;
        $this->_orderRepository = $orderRepository;
        $this->_searchCriteriaBuilder = $searchCriteriaBuilder;
        $this->_credentials = $check;
	$this->_moduleManager = $moduleManager;
	
        parent::__construct($context);
    }

    /**
     * Todos los controladores ejecutan el execute despues de la construccion
     * @return \Magento\Framework\View\Result\Page
     */
    public function execute()
    {

        $oct8ne_context = $this->_oct8necontext->getOct8neContext();

        
        $apiToken = $this->_context->getRequest()->getParam("apiToken");
        $locale = $this->_context->getRequest()->getParam("locale");
        $currency = $this->_context->getRequest()->getParam("currency");
        $id = $this->_context->getRequest()->getParam("reference");       
        $email = $this->_context->getRequest()->getParam("email");   
        
        
        $ordersearch =  $this->_scopeconfig->getValue("Oct8ne/user/ordersearch/0", "default", 'increment_id');
        $orderbyorder = '';
        $orderbyorder = ($ordersearch=='incrementid')  ? 'increment_id' : 'entity_id';



        if (!($this->_credentials->validateToken($apiToken))) return $this->_responseHelper->buildResponse(array());
				
		$this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->addFilter($orderbyorder, $id, 'eq');

        if(!empty($email)) {
		    $this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->addFilter('customer_email', $email, 'eq');
        }

		$this->_searchCriteriaBuilder = $this->_searchCriteriaBuilder->create();


		$orderList = $this->_orderRepository->getList($this->_searchCriteriaBuilder)->getItems();

		$order = reset($orderList);

        if (empty($order)) {

            return $this->_responseHelper->buildResponse(array());

        }

        $currencyOrder = "";
        $total = strval($this->_currencyHelper->convertAndRound($order->getGrandTotal(), NULL,$currency, 2));

        if($oct8ne_context["context_currency"] != $currency) {
            $currencyOrder = $currency;

        } else {
            $currencyOrder = $oct8ne_context["context_currency"];
            $total = $order->getGrandTotal();
        }

        $tracksCollection = $order->getTracksCollection();
        $trackNumbers = array();

        foreach ($tracksCollection->getItems() as $track) {

            $tracknumber = $track->getTrackNumber();
            $trakURL = $track->getUrl();

            $aux = array();
            $aux["trackNumber"] = isset($tracknumber) ? $tracknumber : "";
            $aux["trackURL"] = isset($trakURL) ? $trakURL : "";
            $trackNumbers = $aux;

        }

        $products = array();

        foreach($order->getAllVisibleItems() as $item) {
            $aux = array();
            $aux["quantity"] = strval(intval($item->getQtyOrdered()));
            $aux["name"] =  $item->getName();

            try{
                $productOptions = $item->getProductOptions();
                if(isset($productOptions)){
                    if(isset($productOptions["simple_name"]) && $productOptions["simple_name"] != $aux["name"]){
                        $aux["name"] = $productOptions["simple_name"];
                    }else{
                        if(isset($productOptions["attributes_info"])){
                            $string = "";
                            foreach ($productOptions["attributes_info"] as $attribute) {
                                if(isset($attribute['label']) && isset($attribute['value'])){
                                    $string .= "{$attribute['label']}={$attribute['value']}, ";
                                }
                            }
                            $string = rtrim($string, ", ");
                            $aux["name"] = $item->getName() . " (" . $string . ")";
                        } 
                    }
                }
            } catch (Exception $ex) {
            }
            
            $products[] = $aux;
        }            

        $histories = $order->getStatusHistories();

        $comments = array();

        foreach($histories as $history) {

            $aux = array();
            $aux["message"] = $history->getComment();
            $comments[] = $aux;
        }
        
        $orderincrementid = ($ordersearch=='incrementid')  ? $order->getIncrementId() : $order->getOrderId();
	$estimatedDeliveryDateDatetime = "";
	
        if ($this->_moduleManager->isEnabled('Wyomind_EstimatedDeliveryDate')) {
            //$estimatedDeliveryDate = $order->getEstimatedDeliveryDate();
            $estimatedDeliveryDateDatetime = $order->getEstimatedDeliveryDateDatetime();
            
            if(!empty($estimatedDeliveryDateDatetime)){
                $estimatedDeliveryDateDatetime = explode(" ",$estimatedDeliveryDateDatetime)[0];
            }
        }  
        

        $data = array(
            "date" => $order->getCreatedAt(),
            
            //"reference" => $order->getEntityId(),
            "reference" => $orderincrementid,
            "total" => $total,
            "currency" => $currencyOrder,    
            "labelState" => $order->getStatusLabel(),
            "deliveryDate" => $estimatedDeliveryDateDatetime,
            "carrier" => $order->getShippingMethod(),
			"trackingNumber" => isset($trackNumbers["trackNumber"]) ? $trackNumbers["trackNumber"] : "",
			"trackingURL" => isset($trackNumbers["trackURL"]) ? $trackNumbers["trackURL"] : "",
            "products" => $products,
            "comments" => $comments
        );     
        
    
        return $this->_responseHelper->buildResponse($data);

    }
}